'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const position = require("./types/latlng");
const WebRequest = require("web-request");
const parameters = require("./parameters");
function latLng(latitude, longitude) {
    const result = {
        latitude: latitude,
        longitude: longitude
    };
    position.validateInput(result);
    return result;
}
exports.latLng = latLng;
class Options {
    static radiation() {
        const result = {
            APIKey: null
        };
        return result;
    }
    static power() {
        const result = {
            APIKey: null,
            Capacity: null
        };
        return result;
    }
}
exports.Options = Options;
exports.SolcastConfig = {
    key: process.env.SOLCAST_API_KEY || '',
    url: process.env.SOLCAST_API_URL || 'https://api.solcast.com.au/'
};
function buildUrl(baseUrl, pathAndQuery) {
    let theUrl = (baseUrl || "").trim();
    const path = (pathAndQuery || "").trim();
    if (theUrl.endsWith("/") === false) {
        theUrl = `${theUrl}/`;
    }
    return `${theUrl}${pathAndQuery}`;
}
class Radiation {
    static forecast(point, options) {
        return __awaiter(this, void 0, void 0, function* () {
            position.validateInput(point);
            const url = buildUrl(exports.SolcastConfig.url, 'radiation/forecasts');
            const result = yield WebRequest.json(url, {
                qs: parameters.radiation(point, exports.SolcastConfig, options),
                throwResponseError: true
            });
            return result;
        });
    }
}
exports.Radiation = Radiation;
class Power {
    static forecast(point, options) {
        return __awaiter(this, void 0, void 0, function* () {
            position.validateInput(point);
            const url = buildUrl(exports.SolcastConfig.url, 'pv_power/forecasts');
            const result = yield WebRequest.json(url, {
                qs: parameters.power(point, exports.SolcastConfig, options),
                throwResponseError: true
            });
            return result;
        });
    }
}
exports.Power = Power;
//# sourceMappingURL=index.js.map